@@ -4,7 +4,7 @@ use Imager;
 use vars qw($VERSION @ISA);
 
 BEGIN {
-  $VERSION = "0.02";
+  $VERSION = "0.01";
   
   eval {
     require XSLoader;
@@ -23,9 +23,7 @@ Imager->register_reader
    single => 
    sub { 
      my ($im, $io, %hsh) = @_;
-     my $masked = 
-       exists $hsh{ico_masked} ? $hsh{ico_masked} : 1;
-     $im->{IMG} = i_readico_single($io, $hsh{page} || 0, $masked);
+     $im->{IMG} = i_readico_single($io, $hsh{page} || 0);
 
      unless ($im->{IMG}) {
        $im->_set_error(Imager->_error_as_msg);
@@ -37,9 +35,7 @@ Imager->register_reader
    sub {
      my ($io, %hsh) = @_;
      
-     my $masked = 
-       exists $hsh{ico_masked} ? $hsh{ico_masked} : 1;
-     my @imgs = i_readico_multi($io, $masked);
+     my @imgs = i_readico_multi($io);
      unless (@imgs) {
        Imager->_set_error(Imager->_error_as_msg);
        return;
@@ -57,9 +53,7 @@ Imager->register_reader
    single => 
    sub { 
      my ($im, $io, %hsh) = @_;
-     my $masked = 
-       exists $hsh{ico_masked} ? $hsh{ico_masked} : 1;
-     $im->{IMG} = i_readico_single($io, $hsh{page} || 0, $masked);
+     $im->{IMG} = i_readico_single($io, $hsh{page} || 0);
 
      unless ($im->{IMG}) {
        $im->_set_error(Imager->_error_as_msg);
@@ -71,9 +65,7 @@ Imager->register_reader
    sub {
      my ($io, %hsh) = @_;
      
-     my $masked = 
-       exists $hsh{ico_masked} ? $hsh{ico_masked} : 1;
-     my @imgs = i_readico_multi($io, $masked);
+     my @imgs = i_readico_multi($io);
      unless (@imgs) {
        Imager->_set_error(Imager->_error_as_msg);
        return;
@@ -167,7 +159,7 @@ Imager's MS Icon support is documented in L<Imager::Files>.
 
 =head1 AUTHOR
 
-Tony Cook <tonyc@cpan.org>
+Tony Cook <tony@imager.perl.org>
 
 =head1 SEE ALSO
 
